==> amasty-module-shopby-mftf-2-2.1.0.zip: README.md <==
# Shop by MFTF3

### The current version of tests is for Magento CE 2.3.7 (with Default Magento Sample Data).

Prior to tests running it is required to launch PreConfigureAttributesTest.xml. This test works around Magento bug with
Attribute Options duplication. In order to receive correct run of image checkings it is necessary to store a couple of
images (all required images are stored in Test folder) in magento_root/dev/tests/acceptance/tests/_data folder. In order
to avoid timeout error while tests are running we highly recommend to increase "pageload_timeout:" in
magento_root/dev/tests/acceptance/tests/functional.suite.yml

### The tests are divided into following groups:
- iln (is used for running of all tests. E.g. vendor/bin/mftf run:group ILN -r)
- ilnsmoke (is used for running of all smoke tests)
- ilnregression (is used for running of all regression tests)
- brandattribute (is used for running of all tests which check Brand Attribute functionality)
- catfilter (is used for running of all tests which check Category Filter functionality)
- childcatblock (is used for running of all tests which check Children Categories Block functionality)
- catmetatags (is used for running of all tests which check Category Meta Tags functionality)
- ctd (is used for running of all tests which check Category Title and Description functionality)
- newfilter (is used for running of all tests which check New Filter functionality)
- onsalefilter (is used for running of all tests which check On Sale Filter functionality)
- ratingfilter (is used for running of all tests which check Rating Filter functionality)
- stockfilter (is used for running of all tests which check Stock Filter functionality)
- pricefilter (is used for running of all tests which check Price Filter functionality)
- rtcsettings (is used for running of all tests which check Robots Tag Control settings functionality)
- canonicalsettings (is used for running of all tests which check Canonical URL settings functionality)
- paginationsettings (is used for running of all tests which check Pagination settings functionality)
- seourls (is used for running of all tests which check SEO settings functionality)
- taptfilter (is used for running of all tests which check Custom Price Filter functionality)
- catfilterdisabled (is used for running of all tests which check Category Filter disabling)
- catfiltervisibility (is used for running of all tests which check Category Filter visibility)
- catfilterdisplayproperties (is used for running of all tests which check Category Filter Display Properties settings
  tab)
- catfiltertree (is used for running of all tests which check Category Filter Tree)
- catfiltercompatibility (is used for running of all tests which check Category Filter compatibility with other features
  and settings)
- catfiltermultiselect (is used for running of all tests which check multiselect Category Filter)
- catfilterexclude (is used for running of all tests which check Category Filter with excluded Categories)
- colorfilter (is used for running of all tests which check Color Filter functionality)
- sizefilter (is used for running of all tests which check Size Filter functionality)
- addvertscroll (is used for running of all tests which check Add Vertical Scroll setting)
- excludeoos (is used for running of all tests which check Exclude 'Out of Stock' Configurable Options from Navigation
  setting)
- nouo (is used for running of all tests which check Number of Unfolded Options in State setting)
- sttajax (is used for running of all tests which check Scroll to Top after AJAX Load setting)
- preconfigurationgroup (is used for running of all pre-configuration tests)
- allbrandspage (is used for running of all tests which check All Brands Page functionality)
- brandlogotooltip (is used for running of all tests which check Brand Logo Tooltip functionality)
- brandslider (is used for running of all tests which check Brand Slider functionality)
- brandlink (is used for running of all tests which check Brand Links and Brand List in Top Menu)
- moreftbblock (is used for running of all tests which check More From This Brand Block functionality)
- allproductspagecanonical (is used for running of all tests which check Canonical on All Brands Page)
- catpagescanonical (is used for running of all tests which check Canonical on Category Page)
- pagenumberinmeta (is used for running of all tests which check Page Number in Metadata)
- prevnexttags (is used for running of all tests which check Prev/Next Tags)
- rtsettings (is used for running of all tests which check Robots Tag Control settings tab)
- relnofollow (is used for running of all tests which check rel="nofollow" after Filter Options)
- noindexpagination (is used for running of all tests which check Noindex for Paginated Pages)
- noindexformultioptions (is used for running of all tests which check Noindex for Multiple Filters Applied)
- seodisabling (is used for running of all tests which check disabled SEO settings)
- seoattributename (is used for running of all tests which check SEO settings configuration with enabled Include
  Attribute Code setting)
- seofilterkey (is used for running of all tests which check SEO settings configuration with enabled Filter Key setting)
- fullseo (is used for running of all tests which check SEO settings configuration with enabled settings from SEO URLs
  settings tab)
- seosuffix (is used for running of all tests which check SEO settings configuration with enabled Add Suffix to the
  Brand Pages and All-products Pages setting)
- seoscenario2-3 (is used for running of all tests which check various SEO settings configurations)
- seosmoke (is used for running of all tests which check basic SEO settings configurations)

==> amasty-module-shopby-mftf-3-2.4.3.zip: README.md <==
# Shop by MFTF3

### The current version of tests is for Magento CE 2.4.6 (with Default Magento Sample Data).

Prior to tests running it is required to launch PreConfigureAttributesTest.xml. This test works around Magento bug with
Attribute Options duplication. In order to receive correct run of image checkings it is necessary to store a couple of
images (all required images are stored in Test folder) in magento_root/dev/tests/acceptance/tests/_data folder. In order
to avoid timeout error while tests are running we highly recommend to increase "pageload_timeout:" in
magento_root/dev/tests/acceptance/tests/functional.suite.yml

### The tests are divided into following groups:
- iln (is used for running of all tests. E.g. vendor/bin/mftf run:group ILN -r)
- ilnsmoke (is used for running of all smoke tests)
- ilnregression (is used for running of all regression tests)
- brandattribute (is used for running of all tests which check Brand Attribute functionality)
- catfilter (is used for running of all tests which check Category Filter functionality)
- childcatblock (is used for running of all tests which check Children Categories Block functionality)
- catmetatags (is used for running of all tests which check Category Meta Tags functionality)
- ctd (is used for running of all tests which check Category Title and Description functionality)
- newfilter (is used for running of all tests which check New Filter functionality)
- onsalefilter (is used for running of all tests which check On Sale Filter functionality)
- ratingfilter (is used for running of all tests which check Rating Filter functionality)
- stockfilter (is used for running of all tests which check Stock Filter functionality)
- pricefilter (is used for running of all tests which check Price Filter functionality)
- rtcsettings (is used for running of all tests which check Robots Tag Control settings functionality)
- canonicalsettings (is used for running of all tests which check Canonical URL settings functionality)
- paginationsettings (is used for running of all tests which check Pagination settings functionality)
- seourls (is used for running of all tests which check SEO settings functionality)
- taptfilter (is used for running of all tests which check Custom Price Filter functionality)
- catfilterdisabled (is used for running of all tests which check Category Filter disabling)
- catfiltervisibility (is used for running of all tests which check Category Filter visibility)
- catfilterdisplayproperties (is used for running of all tests which check Category Filter Display Properties settings
  tab)
- catfiltertree (is used for running of all tests which check Category Filter Tree)
- catfiltercompatibility (is used for running of all tests which check Category Filter compatibility with other features
  and settings)
- catfiltermultiselect (is used for running of all tests which check multiselect Category Filter)
- catfilterexclude (is used for running of all tests which check Category Filter with excluded Categories)
- colorfilter (is used for running of all tests which check Color Filter functionality)
- sizefilter (is used for running of all tests which check Size Filter functionality)
- addvertscroll (is used for running of all tests which check Add Vertical Scroll setting)
- excludeoos (is used for running of all tests which check Exclude 'Out of Stock' Configurable Options from Navigation
  setting)
- nouo (is used for running of all tests which check Number of Unfolded Options in State setting)
- sttajax (is used for running of all tests which check Scroll to Top after AJAX Load setting)
- preconfigurationgroup (is used for running of all pre-configuration tests)
- allbrandspage (is used for running of all tests which check All Brands Page functionality)
- brandlogotooltip (is used for running of all tests which check Brand Logo Tooltip functionality)
- brandslider (is used for running of all tests which check Brand Slider functionality)
- brandlink (is used for running of all tests which check Brand Links and Brand List in Top Menu)
- moreftbblock (is used for running of all tests which check More From This Brand Block functionality)
- allproductspagecanonical (is used for running of all tests which check Canonical on All Brands Page)
- catpagescanonical (is used for running of all tests which check Canonical on Category Page)
- pagenumberinmeta (is used for running of all tests which check Page Number in Metadata)
- prevnexttags (is used for running of all tests which check Prev/Next Tags)
- rtsettings (is used for running of all tests which check Robots Tag Control settings tab)
- relnofollow (is used for running of all tests which check rel="nofollow" after Filter Options)
- noindexpagination (is used for running of all tests which check Noindex for Paginated Pages)
- noindexformultioptions (is used for running of all tests which check Noindex for Multiple Filters Applied)
- seodisabling (is used for running of all tests which check disabled SEO settings)
- seoattributename (is used for running of all tests which check SEO settings configuration with enabled Include
  Attribute Code setting)
- seofilterkey (is used for running of all tests which check SEO settings configuration with enabled Filter Key setting)
- fullseo (is used for running of all tests which check SEO settings configuration with enabled settings from SEO URLs
  settings tab)
- seosuffix (is used for running of all tests which check SEO settings configuration with enabled Add Suffix to the
  Brand Pages and All-products Pages setting)
- seoscenario2-3 (is used for running of all tests which check various SEO settings configurations)
- seosmoke (is used for running of all tests which check basic SEO settings configurations)
- brandpagescanonical (is used for running of all tests which check Canonical on Brand Page)
- stickysdbr (is used for running of all tests which check Enable Sticky Sidebar for Desktop setting)
- allprodpage (is used for running of all tests which check All-products Page)
- custpage(is used for running of all tests which check Custom Page functionality)
